/////////////////////////////////////////////////////////////////////////////////
//
// This file is part of SACAMOS, cable models for EMI simulations in SPICE.
// It was developed by the University of Nottingham and the Netherlands Aerospace
// Centre (NLR) for ESA under contract number 4000112765/14/NL/HK.
//
// Copyright (C) 2015 - 2017 University of Nottingham
//
// SACAMOS is free software: you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation, either version 3 of the License, or (at your option) any later
// version.
//
// SACAMOS is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
// or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// A copy of the GNU General Public License version 3 can be found in the
// file GNU_GPL_v3 in the root or at <http://www.gnu.org/licenses/>.
//
// wxWidgets is currently licenced under the "wxWindows Library Licence".
// A copy of the wxWindows Library Licence, Version 3.1 can be found in the file
// wxWindows_Library_Licence_v3-1 in the root or at:
// <https://www.wxwidgets.org/about/licence/>
//
// The University of Nottingham can be contacted at: ggiemr@nottingham.ac.uk
//
// File Contents:
//
// NAME
//     FLEXCABLE.cpp
//
// DESCRIPTION
//     GUI for the construction of cable_spec file for cable type: Flexcable
//
// AUTHOR(S)
//     Steve Greedy
//
/////////////////////////////////////////////////////////////////////////////////
#include "FLEXCABLE.h"

//(*InternalHeaders(FLEXCABLE)
#include <wx/settings.h>
#include <wx/intl.h>
#include <wx/string.h>
//*)

//(*IdInit(FLEXCABLE)
const long FLEXCABLE::ID_STATICTEXT1 = wxNewId();
const long FLEXCABLE::ID_TEXTCTRL1 = wxNewId();
const long FLEXCABLE::ID_STATICTEXT16 = wxNewId();
const long FLEXCABLE::ID_TEXTCTRL13 = wxNewId();
const long FLEXCABLE::ID_STATICTEXT2 = wxNewId();
const long FLEXCABLE::ID_TEXTCTRL2 = wxNewId();
const long FLEXCABLE::ID_STATICTEXT3 = wxNewId();
const long FLEXCABLE::ID_TEXTCTRL3 = wxNewId();
const long FLEXCABLE::ID_STATICTEXT17 = wxNewId();
const long FLEXCABLE::ID_TEXTCTRL14 = wxNewId();
const long FLEXCABLE::ID_GRID1 = wxNewId();
const long FLEXCABLE::ID_STATICTEXT4 = wxNewId();
const long FLEXCABLE::ID_CHECKBOX2 = wxNewId();
const long FLEXCABLE::ID_STATICTEXT5 = wxNewId();
const long FLEXCABLE::ID_COMBOBOX1 = wxNewId();
const long FLEXCABLE::ID_STATICTEXT6 = wxNewId();
const long FLEXCABLE::ID_CHECKBOX3 = wxNewId();
const long FLEXCABLE::ID_PANEL2 = wxNewId();
const long FLEXCABLE::ID_STATICTEXT12 = wxNewId();
const long FLEXCABLE::ID_TEXTCTRL12 = wxNewId();
const long FLEXCABLE::ID_STATICTEXT13 = wxNewId();
const long FLEXCABLE::ID_STATICTEXT14 = wxNewId();
const long FLEXCABLE::ID_STATICTEXT15 = wxNewId();
const long FLEXCABLE::ID_CHECKBOX1 = wxNewId();
const long FLEXCABLE::ID_PANEL3 = wxNewId();
const long FLEXCABLE::ID_NOTEBOOK1 = wxNewId();
const long FLEXCABLE::ID_BUTTON1 = wxNewId();
const long FLEXCABLE::ID_BUTTON2 = wxNewId();
const long FLEXCABLE::ID_BUTTON3 = wxNewId();
const long FLEXCABLE::ID_PANEL1 = wxNewId();
//*)

BEGIN_EVENT_TABLE(FLEXCABLE,wxDialog)
	//(*EventTable(FLEXCABLE)
	//*)
END_EVENT_TABLE()

FLEXCABLE::FLEXCABLE(wxWindow* parent,wxWindowID id,const wxPoint& pos,const wxSize& size)
{
	//(*Initialize(FLEXCABLE)
	wxBoxSizer* BoxSizer4;
	wxStaticBoxSizer* StaticBoxSizer2;
	wxBoxSizer* BoxSizer6;
	wxFlexGridSizer* FlexGridSizer4;
	wxBoxSizer* BoxSizer5;
	wxBoxSizer* BoxSizer7;
	wxFlexGridSizer* FlexGridSizer3;
	wxFlexGridSizer* FlexGridSizer5;
	wxFlexGridSizer* FlexGridSizer2;
	wxBoxSizer* BoxSizer2;
	wxBoxSizer* BoxSizer1;
	wxStaticBoxSizer* StaticBoxSizer1;
	wxFlexGridSizer* FlexGridSizer1;
	wxBoxSizer* BoxSizer3;

	Create(parent, wxID_ANY, _("SACAMOS: FLAXCABLE MODEL"), wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE, _T("wxID_ANY"));
	FlexGridSizer1 = new wxFlexGridSizer(0, 2, 0, 0);
	StaticBoxSizer1 = new wxStaticBoxSizer(wxVERTICAL, this, _("Flex Cable Parameters"));
	FlexGridSizer2 = new wxFlexGridSizer(0, 1, 0, 0);
	BoxSizer1 = new wxBoxSizer(wxHORIZONTAL);
	StaticText1 = new wxStaticText(this, ID_STATICTEXT1, _("Cabe Name"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT1"));
	BoxSizer1->Add(StaticText1, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
	TextCtrl1 = new wxTextCtrl(this, ID_TEXTCTRL1, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_TEXTCTRL1"));
	BoxSizer1->Add(TextCtrl1, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
	FlexGridSizer2->Add(BoxSizer1, 1, wxALL|wxEXPAND, 5);
	BoxSizer3 = new wxBoxSizer(wxVERTICAL);
	Notebook1 = new wxNotebook(this, ID_NOTEBOOK1, wxDefaultPosition, wxDefaultSize, 0, _T("ID_NOTEBOOK1"));
	Panel2 = new wxPanel(Notebook1, ID_PANEL2, wxDefaultPosition, wxDefaultSize, wxTAB_TRAVERSAL, _T("ID_PANEL2"));
	BoxSizer5 = new wxBoxSizer(wxVERTICAL);
	BoxSizer6 = new wxBoxSizer(wxVERTICAL);
	FlexGridSizer3 = new wxFlexGridSizer(0, 2, 0, 0);
	StaticText16 = new wxStaticText(Panel2, ID_STATICTEXT16, _("Number of Conductor Rows"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT16"));
	FlexGridSizer3->Add(StaticText16, 1, wxALL|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
	TextCtrl13 = new wxTextCtrl(Panel2, ID_TEXTCTRL13, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxTE_PROCESS_ENTER, wxDefaultValidator, _T("ID_TEXTCTRL13"));
	FlexGridSizer3->Add(TextCtrl13, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
	StaticText2 = new wxStaticText(Panel2, ID_STATICTEXT2, _("Dielectric Width x, (m)"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT2"));
	FlexGridSizer3->Add(StaticText2, 1, wxALL|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
	TextCtrl2 = new wxTextCtrl(Panel2, ID_TEXTCTRL2, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_TEXTCTRL2"));
	FlexGridSizer3->Add(TextCtrl2, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
	StaticText3 = new wxStaticText(Panel2, ID_STATICTEXT3, _("Dielectric Height, y (m)"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT3"));
	FlexGridSizer3->Add(StaticText3, 1, wxALL|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
	TextCtrl3 = new wxTextCtrl(Panel2, ID_TEXTCTRL3, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_TEXTCTRL3"));
	FlexGridSizer3->Add(TextCtrl3, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
	StaticText17 = new wxStaticText(Panel2, ID_STATICTEXT17, _("Conductor Conductivity (S/m)"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT17"));
	FlexGridSizer3->Add(StaticText17, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
	TextCtrl14 = new wxTextCtrl(Panel2, ID_TEXTCTRL14, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_TEXTCTRL14"));
	FlexGridSizer3->Add(TextCtrl14, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
	BoxSizer6->Add(FlexGridSizer3, 0, wxALIGN_LEFT, 0);
	BoxSizer5->Add(BoxSizer6, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
	BoxSizer7 = new wxBoxSizer(wxHORIZONTAL);
	Grid1 = new wxGrid(Panel2, ID_GRID1, wxDefaultPosition, wxDefaultSize, wxSIMPLE_BORDER|wxVSCROLL|wxHSCROLL|wxFULL_REPAINT_ON_RESIZE, _T("ID_GRID1"));
	BoxSizer7->Add(Grid1, 3, wxALL|wxEXPAND, 5);
	BoxSizer5->Add(BoxSizer7, 1, wxALL|wxEXPAND, 5);
	FlexGridSizer4 = new wxFlexGridSizer(0, 2, 0, 0);
	StaticText4 = new wxStaticText(Panel2, ID_STATICTEXT4, _("Use Laplace"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT4"));
	FlexGridSizer4->Add(StaticText4, 1, wxALL|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
	CheckBox2 = new wxCheckBox(Panel2, ID_CHECKBOX2, _("Yes"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_CHECKBOX2"));
	CheckBox2->SetValue(true);
	CheckBox2->Disable();
	FlexGridSizer4->Add(CheckBox2, 1, wxALL|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
	StaticText5 = new wxStaticText(Panel2, ID_STATICTEXT5, _("View Mesh"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT5"));
	FlexGridSizer4->Add(StaticText5, 1, wxALL|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
	ComboBox1 = new wxComboBox(Panel2, ID_COMBOBOX1, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, 0, 0, wxDefaultValidator, _T("ID_COMBOBOX1"));
	FlexGridSizer4->Add(ComboBox1, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
	StaticText6 = new wxStaticText(Panel2, ID_STATICTEXT6, _("Refine Mesh"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT6"));
	FlexGridSizer4->Add(StaticText6, 1, wxALL|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
	CheckBox3 = new wxCheckBox(Panel2, ID_CHECKBOX3, _("Yes"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_CHECKBOX3"));
	CheckBox3->SetValue(false);
	CheckBox3->Disable();
	FlexGridSizer4->Add(CheckBox3, 1, wxALL|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
	BoxSizer5->Add(FlexGridSizer4, 1, wxALL|wxEXPAND, 5);
	Panel2->SetSizer(BoxSizer5);
	BoxSizer5->Fit(Panel2);
	BoxSizer5->SetSizeHints(Panel2);
	Panel3 = new wxPanel(Notebook1, ID_PANEL3, wxDefaultPosition, wxDefaultSize, wxTAB_TRAVERSAL, _T("ID_PANEL3"));
	BoxSizer4 = new wxBoxSizer(wxVERTICAL);
	FlexGridSizer5 = new wxFlexGridSizer(0, 2, 0, 0);
	StaticText12 = new wxStaticText(Panel3, ID_STATICTEXT12, _("Dielectric Permittivity"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT12"));
	FlexGridSizer5->Add(StaticText12, 1, wxALL|wxALIGN_LEFT|wxALIGN_CENTER_VERTICAL, 5);
	TextCtrl12 = new wxTextCtrl(Panel3, ID_TEXTCTRL12, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_TEXTCTRL12"));
	FlexGridSizer5->Add(TextCtrl12, 1, wxALL|wxALIGN_RIGHT|wxALIGN_CENTER_VERTICAL, 5);
	StaticText13 = new wxStaticText(Panel3, ID_STATICTEXT13, _("Or"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT13"));
	FlexGridSizer5->Add(StaticText13, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
	StaticText14 = new wxStaticText(Panel3, ID_STATICTEXT14, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT14"));
	FlexGridSizer5->Add(StaticText14, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
	StaticText15 = new wxStaticText(Panel3, ID_STATICTEXT15, _("Frequency Dependent Model"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT15"));
	FlexGridSizer5->Add(StaticText15, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
	CheckBox1 = new wxCheckBox(Panel3, ID_CHECKBOX1, _("Yes"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_CHECKBOX1"));
	CheckBox1->SetValue(false);
	FlexGridSizer5->Add(CheckBox1, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
	BoxSizer4->Add(FlexGridSizer5, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
	Panel3->SetSizer(BoxSizer4);
	BoxSizer4->Fit(Panel3);
	BoxSizer4->SetSizeHints(Panel3);
	Notebook1->AddPage(Panel2, _("General"), false);
	Notebook1->AddPage(Panel3, _("Material"), false);
	BoxSizer3->Add(Notebook1, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
	FlexGridSizer2->Add(BoxSizer3, 0, wxALL|wxEXPAND, 5);
	StaticBoxSizer1->Add(FlexGridSizer2, 10, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
	BoxSizer2 = new wxBoxSizer(wxHORIZONTAL);
	Button1 = new wxButton(this, ID_BUTTON1, _("SAVE"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_BUTTON1"));
	BoxSizer2->Add(Button1, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
	Button2 = new wxButton(this, ID_BUTTON2, _("BUILD"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_BUTTON2"));
	BoxSizer2->Add(Button2, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
	Button3 = new wxButton(this, ID_BUTTON3, _("CLOSE"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_BUTTON3"));
	BoxSizer2->Add(Button3, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
	StaticBoxSizer1->Add(BoxSizer2, 1, wxALL|wxEXPAND, 5);
	FlexGridSizer1->Add(StaticBoxSizer1, 1, wxALL|wxEXPAND, 5);
	StaticBoxSizer2 = new wxStaticBoxSizer(wxHORIZONTAL, this, _("Cross Section"));
	Panel1 = new wxPanel(this, ID_PANEL1, wxDefaultPosition, wxSize(500,500), wxTAB_TRAVERSAL, _T("ID_PANEL1"));
	Panel1->SetBackgroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOW));
	Panel1->SetToolTip(_("Double Click to Reset Schematic"));
	StaticBoxSizer2->Add(Panel1, 1, wxALL|wxALIGN_TOP, 5);
	FlexGridSizer1->Add(StaticBoxSizer2, 1, wxALL|wxALIGN_TOP|wxALIGN_CENTER_HORIZONTAL, 5);
	SetSizer(FlexGridSizer1);
	FlexGridSizer1->Fit(this);
	FlexGridSizer1->SetSizeHints(this);

	Connect(ID_TEXTCTRL13,wxEVT_COMMAND_TEXT_UPDATED,(wxObjectEventFunction)&FLEXCABLE::OnTextCtrl13Text);
	Connect(ID_TEXTCTRL13,wxEVT_COMMAND_TEXT_ENTER,(wxObjectEventFunction)&FLEXCABLE::OnTextCtrl13TextEnter);
	Connect(ID_TEXTCTRL2,wxEVT_COMMAND_TEXT_UPDATED,(wxObjectEventFunction)&FLEXCABLE::OnTextCtrl2Text);
	Connect(ID_TEXTCTRL3,wxEVT_COMMAND_TEXT_UPDATED,(wxObjectEventFunction)&FLEXCABLE::OnTextCtrl3Text);
	Connect(ID_CHECKBOX3,wxEVT_COMMAND_CHECKBOX_CLICKED,(wxObjectEventFunction)&FLEXCABLE::OnCheckBox3Click);
	Connect(ID_TEXTCTRL12,wxEVT_COMMAND_TEXT_UPDATED,(wxObjectEventFunction)&FLEXCABLE::OnTextCtrl12Text);
	Connect(ID_CHECKBOX1,wxEVT_COMMAND_CHECKBOX_CLICKED,(wxObjectEventFunction)&FLEXCABLE::OnCheckBox1Click);
	Connect(ID_NOTEBOOK1,wxEVT_COMMAND_NOTEBOOK_PAGE_CHANGING,(wxObjectEventFunction)&FLEXCABLE::OnNotebook1PageChanging);
	Connect(ID_BUTTON1,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&FLEXCABLE::OnButton1Click);
	Connect(ID_BUTTON2,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&FLEXCABLE::OnButton2Click);
	Connect(ID_BUTTON3,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&FLEXCABLE::OnButton3Click);
	Panel1->Connect(wxEVT_PAINT,(wxObjectEventFunction)&FLEXCABLE::OnPanel1Paint,0,this);
	Panel1->Connect(wxEVT_LEFT_DCLICK,(wxObjectEventFunction)&FLEXCABLE::OnPanel1LeftDClick,0,this);
	Connect(wxID_ANY,wxEVT_INIT_DIALOG,(wxObjectEventFunction)&FLEXCABLE::OnInit);
	Connect(wxEVT_PAINT,(wxObjectEventFunction)&FLEXCABLE::OnPaint);
	//*)
}


FLEXCABLE::~FLEXCABLE()
{
	//(*Destroy(FLEXCABLE)
	//*)
}


void FLEXCABLE::OnInit(wxInitDialogEvent& event)
{
    TextCtrl2->Bind(wxEVT_SET_FOCUS,(wxObjectEventFunction)&FLEXCABLE::OnHighlightSchematic, this);
    TextCtrl3->Bind(wxEVT_SET_FOCUS,(wxObjectEventFunction)&FLEXCABLE::OnHighlightSchematic, this);
    TextCtrl12->Bind(wxEVT_SET_FOCUS,(wxObjectEventFunction)&FLEXCABLE::OnHighlightSchematic, this);
    TextCtrl14->Bind(wxEVT_SET_FOCUS,(wxObjectEventFunction)&FLEXCABLE::OnHighlightSchematic, this);
    CheckBox1->Bind(wxEVT_SET_FOCUS,(wxObjectEventFunction)&FLEXCABLE::OnHighlightSchematic, this);
    Grid1->Bind(wxEVT_SET_FOCUS,(wxObjectEventFunction)&FLEXCABLE::OnHighlightSchematic, this);
}

void FLEXCABLE::OnPaint(wxPaintEvent& event)
{
    if (EDIT_EXISTING==true) EditExistingCable();
}

void FLEXCABLE::SetPathToMOD(wxString Path, wxString Name)
{
    pathToMOD << Path;
    MODname << Name;
}

void FLEXCABLE::OnButton1Click(wxCommandEvent& event)
{
    int IsError = 0;

    wxString fileName = TextCtrl1->GetValue();

    TextCtrl1->SetBackgroundColour(wxColor(255,255,255));

    if (fileName == "")
    {
        wxMessageBox("Please Specify a Cable Name" , _("Missing Cable Name"));
        return;
    }

    check_is_empty(TextCtrl2, &IsError);
    check_is_empty(TextCtrl3, &IsError);
    check_is_empty(TextCtrl13, &IsError);
    check_is_empty(TextCtrl14, &IsError);

    if (!CheckBox1->GetValue())
    {
        check_is_empty(TextCtrl12, &IsError);
    }

    if ( IsError == 1)
    {
        wxMessageBox("Please fix highlighted errors" , _("Non numeric entry"));
        return;
    }

    WriteCableFile (fileName);

    Button1->Disable();
}

void FLEXCABLE::OnCheckBox1Click(wxCommandEvent& event)
{

    TextCtrl12->Disable();

    FD_ESR *winFD_ESR = new FD_ESR(this);

    winFD_ESR->formtype = 1;

    if ( winFD_ESR->ShowModal() == wxID_OK )
    {
        FD_ESR6 = winFD_ESR->TextCtrl6->GetValue();
        FD_ESR7 = winFD_ESR->TextCtrl7->GetValue();
        FD_ESR8 = winFD_ESR->TextCtrl8->GetValue();
        FD_ESR9 = winFD_ESR->TextCtrl9->GetValue();
        FD_ESR10= winFD_ESR->TextCtrl10->GetValue();
    }
    winFD_ESR->Destroy();

}

void FLEXCABLE::OnButton2Click(wxCommandEvent& event)
{
    //CABLE BUIDER
    wxString fileName = TextCtrl1->GetValue();
    wxString command_line;

    wxString separator(wxFileName::GetPathSeparator());

    std::stringstream stream;

    stream  <<"." + separator
            << "cable_model_builder"
            << " "
            << ".." + separator + MODname + separator + "CABLE" + separator
            << fileName ;

    command_line << stream.str().c_str();

    wxExecute (command_line);

    // Display Run Status
    RUN_STATUS *run_status = new RUN_STATUS(this);
    run_status->ShowModal();

    Button1->Enable();

    if (CheckBox2->GetValue())
    {

        wxString pattern (("*.msh.vtk")) ;

        wxString file;

        ComboBox1->Clear();

        file = wxFindFirstFile(pattern);

        while ( !file.empty())
        {
                wxString meshfile = file;
                size_t extindex = meshfile.find_last_of (".");

                meshfile  = meshfile.substr(0, extindex);

                extindex = meshfile.find_last_of (".");

                meshfile  = meshfile.substr(0, extindex);

                meshfile = meshfile.substr(2,meshfile.length());

                ComboBox1->Append(meshfile);

                file = wxFindNextFile();
        }

        CheckBox3->Enable();
    }
}

void FLEXCABLE::OnButton3Click(wxCommandEvent& event)
{
    //clean up directory
    clean_temp_files();
    Close();
}

void FLEXCABLE::OnTextCtrl2Text(wxCommandEvent& event)
{
    int IsError = 0;
    check_is_numeric(TextCtrl2, &IsError);
    check_is_positive(TextCtrl2, &IsError);
}

void FLEXCABLE::OnTextCtrl3Text(wxCommandEvent& event)
{
    int IsError = 0;
    check_is_numeric(TextCtrl3, &IsError);
    check_is_positive(TextCtrl3, &IsError);
}

void FLEXCABLE::OnTextCtrl12Text(wxCommandEvent& event)
{
    int IsError = 0;
    check_is_numeric(TextCtrl12, &IsError);
    check_is_positive(TextCtrl2, &IsError);
}

void FLEXCABLE::OnTextCtrl13Text(wxCommandEvent& event)
{
    int IsError = 0;
    check_is_numeric(TextCtrl13, &IsError);
    check_is_positive(TextCtrl3, &IsError);

    double value_tb13;
    wxString contents_tb13;

    contents_tb13 = TextCtrl13->GetValue();

    contents_tb13.ToDouble(&value_tb13);

    if (floor(value_tb13) != ceil(value_tb13) || value_tb13 < 1)
    {
        TextCtrl13->SetBackgroundColour(wxColor(255,153,153));
        TextCtrl13->SetFocus();
        IsError = 1;
    }
}

void FLEXCABLE::WriteCableFile (wxString fileName)
{
    ofstream cableFile;

    wxString separator(wxFileName::GetPathSeparator());

    wxString fullFileName = pathToMOD + separator + "CABLE" + separator + fileName + ".cable_spec";

    cableFile.open (fullFileName);

    int n_rows, n_conductors, row;

    n_conductors = 0;

    n_rows = wxAtoi(TextCtrl13->GetValue());

    for (int i = 0; i < n_rows; i++){

        wxString conductors = Grid1->GetCellValue(i,5);

        n_conductors  = n_conductors + wxAtoi(conductors);

    }

    int n_parameters = (n_rows * 6) + 4;

    if (cableFile.is_open())
    {
        cableFile <<"# MOD_cable_lib_dir \n";
        cableFile <<".." << separator << MODname << separator << "CABLE" << separator <<"\n";
        cableFile <<"flex_cable\n";
        cableFile << n_conductors <<" #number of conductors \n";
        cableFile << n_parameters <<" #number of parameters \n";

        cableFile << TextCtrl2->GetValue() <<" # parameter 1: dielectric width (x dimension)\n";
        cableFile << TextCtrl3->GetValue() <<" # parameter 2: dielectric height (y dimension)\n";
        cableFile << TextCtrl13->GetValue() <<" # parameter 3: number of rows of conductors\n";

        for (row = 0; row < n_rows;row++){

            cableFile << Grid1->GetCellValue(row,0) <<" # parameter "<< (row * 6) + 4 <<": row "<<row+1<<" centre offset x\n";
            cableFile << Grid1->GetCellValue(row,1) <<" # parameter "<< (row * 6) + 5 <<": row "<<row+1<<" centre offset y\n";
            cableFile << Grid1->GetCellValue(row,2) <<" # parameter "<< (row * 6) + 6 <<": row "<<row+1<<" conductor width (x dimension)\n";
            cableFile << Grid1->GetCellValue(row,3) <<" # parameter "<< (row * 6) + 7 <<": row "<<row+1<<" conductor width (y dimension)\n";
            cableFile << Grid1->GetCellValue(row,4) <<" # parameter "<< (row * 6) + 8 <<": row "<<row+1<<" conductor separation\n";
            cableFile << Grid1->GetCellValue(row,5) <<" # parameter "<< (row * 6) + 9 <<": row "<<row+1<<" number of conductors\n";
        }

        cableFile << TextCtrl14->GetValue() <<" # parameter "<< ((row-1) * 6) + 10<<": conductivity\n";

        cableFile <<"1 # number of frequency dependent parameters\n";

        if (CheckBox1->GetValue()){
            cableFile << "# Dielectric relative permittivity model follows\n";
            cableFile << FD_ESR6 <<" # w normalisation constant\n";
            cableFile << FD_ESR7 <<" # a order, a coefficients follow below\n";
            cableFile << FD_ESR8 <<" \n";
            cableFile << FD_ESR9 <<" # b order, b coefficients follow below\n";
            cableFile << FD_ESR10 <<" \n";
        }

        else{
            cableFile << "# Dielectric relative permittivity model follows\n";
            cableFile << "1.0 # w normalisation constant\n";
            cableFile << "0 # a order, a coefficients follow below\n";
            cableFile << TextCtrl12->GetValue()<<"\n";
            cableFile << "0 # b order, b coefficients follow below\n";
            cableFile << "1.0\n";
        }

        cableFile <<"use_laplace \n";

        if (CheckBox2->GetValue())
        {
            //cableFile << "Laplace_boundary_constant\n";
            //cableFile << MESH_PARAM1 <<"\n";
            cableFile << "Laplace_surface_mesh_constant\n";
            cableFile << MESH_PARAM2 <<"\n";
            //cableFile << "max_mesh_edge_length\n";
            //cableFile << MESH_PARAM3 <<"\n";

            CheckBox2 ->SetValue(false);
        }

        cableFile.close();
    }
}

void FLEXCABLE::OnPanel1Paint(wxPaintEvent& event)
{
    flexcableSchematic();
}

void FLEXCABLE::flexcableSchematic()
{
    int size_h, size_v;
    Panel1->GetSize(&size_h, &size_v );

    wxClientDC dc(Panel1);
    dc.Clear();

    // Draw centre lines
    dc.SetPen( wxPen( wxColor(224,224,224),1 , wxDOT_DASH) );
    dc.DrawLine( 0, size_v/2, size_h,size_v/2 );
    dc.DrawLine( size_h/2, 0, size_h/2, size_v);

    dc.SetTextForeground(*wxBLUE);
    dc.DrawText("General Multi-layer Flexcable", 10, 15);

    float conductor_width_r1, conductor_height_r1, conductor_width_r2, conductor_height_r2,conductor_width_r3, conductor_height_r3,conductor_separation_r1, conductor_separation_r2,totalHeight, totalWidth;

    conductor_width_r1 = 0.175 * size_h;
    conductor_height_r1 = 0.06 * size_v;

    conductor_width_r2 = 0.175 * size_h;
    conductor_height_r2 = 0.04 * size_v;

    conductor_width_r3 = 0.9 * size_h;
    conductor_height_r3 = 0.02 * size_v;

    conductor_separation_r1 = 0.05 * size_h;
    conductor_separation_r2 = 0.1 * size_h;

    totalHeight = 0.5 * size_v;
    totalWidth = 0.98 * size_h;

    dc.SetPen( wxPen( wxColor(192,192,192),1 ) );
    dc.SetBrush(wxBrush(wxColor(224,224,224), wxBDIAGONAL_HATCH));
    dc.DrawRectangle(wxPoint(size_h/2-totalWidth/2, size_v/2-totalHeight/2), wxSize(totalWidth,totalHeight));

    dc.SetBrush(wxBrush(wxColor(224,224,224), wxSOLID));

    //row 1
    dc.DrawRectangle(wxPoint(size_h/2- 2 * conductor_width_r1 - 2 * conductor_separation_r1, size_v/3-conductor_height_r1/2), wxSize(conductor_width_r1,conductor_height_r1));
    dc.DrawRectangle(wxPoint(size_h/2- conductor_width_r1 - conductor_separation_r1, size_v/3-conductor_height_r1/2), wxSize(conductor_width_r1,conductor_height_r1));
    dc.DrawRectangle(wxPoint(size_h/2 + conductor_width_r1 + conductor_separation_r1 , size_v/3-conductor_height_r1/2), wxSize(conductor_width_r1,conductor_height_r1));

    //row 2
    dc.DrawRectangle(wxPoint(size_h/2 - 1.5 * conductor_width_r2 - conductor_separation_r2, size_v/2-conductor_height_r2), wxSize(conductor_width_r2,conductor_height_r2));
    dc.DrawRectangle(wxPoint(size_h/2 - conductor_width_r2/2, size_v/2-conductor_height_r2), wxSize(conductor_width_r2,conductor_height_r2));

    // row n
    dc.DrawRectangle(wxPoint(size_h/2 - conductor_width_r3/2, size_v/2 + totalHeight/4 ), wxSize(conductor_width_r3,conductor_height_r3));

    dc.SetPen( wxPen( wxColor(0,0,0),2, wxDOT ) );
    dc.DrawLine( size_h/2 - conductor_separation_r1 , size_v/3, size_h/2 + conductor_width_r1 + conductor_separation_r1, size_v/3);
    dc.DrawLine( size_h/2 - conductor_width_r2/2 , size_v/2 - conductor_height_r2/2 , size_h/2 - conductor_width_r2/2 - conductor_separation_r2, size_v/2 - conductor_height_r2/2);

    dc.SetPen( wxPen( wxColor(51,51,255),1 , wxDOT_DASH) );
    dc.DrawLine( size_h*0.2, size_v/2-conductor_height_r2/2, size_h*0.7,size_v/2-conductor_height_r2/2 );
    dc.DrawLine( size_h/2-conductor_width_r2/2-conductor_separation_r2/2, size_v/2-conductor_height_r2, size_h/2-conductor_width_r2/2-conductor_separation_r2/2,size_v/2+conductor_height_r2 );

    wxPoint arrowHead[3];

    dc.SetPen(wxPen(wxColor(51,51,255), 3));
    dc.SetBrush(wxBrush(wxColor(51,51,255), wxSOLID));
    dc.DrawLine( size_h/2-conductor_width_r2/2-conductor_separation_r2/2,size_v/2-conductor_height_r2*2, size_h/2,size_v/2-conductor_height_r2*2 );

    arrowHead[0] = wxPoint(size_h/2-conductor_width_r2/2-conductor_separation_r2/2,size_v/2-conductor_height_r2*2);
    arrowHead[1] = wxPoint(size_h/2-conductor_width_r2/2-conductor_separation_r2/2+5,size_v/2-conductor_height_r2*2-3);
    arrowHead[2] = wxPoint(size_h/2-conductor_width_r2/2-conductor_separation_r2/2+5,size_v/2-conductor_height_r2*2+3);
    dc.DrawPolygon(WXSIZEOF(arrowHead), arrowHead);

    arrowHead[0] = wxPoint(size_h/2,size_v/2-conductor_height_r2*2);
    arrowHead[1] = wxPoint(size_h/2 -5,size_v/2-conductor_height_r2*2-3);
    arrowHead[2] = wxPoint(size_h/2 -5,size_v/2-conductor_height_r2*2+3);
    dc.DrawPolygon(WXSIZEOF(arrowHead), arrowHead);

    arrowHead[0] = wxPoint(size_h*0.65,size_v/2);
    arrowHead[1] = wxPoint(size_h*0.65 - 3,size_v/2 + 5);
    arrowHead[2] = wxPoint(size_h*0.65 + 3,size_v/2 + 5);
    dc.DrawPolygon(WXSIZEOF(arrowHead), arrowHead);

    arrowHead[0] = wxPoint(size_h*0.65,size_v/2 - conductor_height_r2/2);
    arrowHead[1] = wxPoint(size_h*0.65 - 3,size_v/2 - conductor_height_r2/2 - 5);
    arrowHead[2] = wxPoint(size_h*0.65 + 3,size_v/2 - conductor_height_r2/2 - 5);
    dc.DrawPolygon(WXSIZEOF(arrowHead), arrowHead);

    dc.SetTextForeground(*wxBLUE);
    dc.DrawText("offset x", size_h/2 + 3,size_v/2-conductor_height_r2*2 - 10);
    dc.DrawText("offset y", size_h*0.65,size_v/2 - conductor_height_r2/2 + 15);
    dc.DrawText("h", 45,size_v/2 - conductor_height_r2/2-10);
    dc.DrawText("w", 100,size_v/2 + 20);
    dc.DrawText("s", 180,size_v/2 + 20);




    dc.DrawLine( size_h/2-conductor_width_r2 * 1.5 - conductor_separation_r2,size_v/2 + conductor_height_r2, size_h/2-conductor_width_r2 * 0.5 - conductor_separation_r2,size_v/2 + conductor_height_r2 );
    dc.DrawLine( size_h/2-conductor_width_r2 * 0.5 - conductor_separation_r2,size_v/2 + conductor_height_r2, size_h/2-conductor_width_r2 * 0.5,size_v/2 + conductor_height_r2 );

    arrowHead[0] = wxPoint(size_h/2-conductor_width_r2 * 1.5 - conductor_separation_r2,size_v/2 + conductor_height_r2);
    arrowHead[1] = wxPoint(size_h/2-conductor_width_r2 * 1.5 - conductor_separation_r2+5,size_v/2 + conductor_height_r2-3);
    arrowHead[2] = wxPoint(size_h/2-conductor_width_r2 * 1.5 - conductor_separation_r2+5,size_v/2 + conductor_height_r2+3);
    dc.DrawPolygon(WXSIZEOF(arrowHead), arrowHead);

    arrowHead[0] = wxPoint(size_h/2-conductor_width_r2 * 0.5 - conductor_separation_r2,size_v/2 + conductor_height_r2);
    arrowHead[1] = wxPoint(size_h/2-conductor_width_r2 * 0.5 - conductor_separation_r2 -5,size_v/2 + conductor_height_r2-3);
    arrowHead[2] = wxPoint(size_h/2-conductor_width_r2 * 0.5 - conductor_separation_r2 -5,size_v/2 + conductor_height_r2+3);
    dc.DrawPolygon(WXSIZEOF(arrowHead), arrowHead);

    arrowHead[0] = wxPoint(size_h/2-conductor_width_r2 * 0.5 - conductor_separation_r2,size_v/2 + conductor_height_r2);
    arrowHead[1] = wxPoint(size_h/2-conductor_width_r2 * 0.5 - conductor_separation_r2 +5,size_v/2 + conductor_height_r2-3);
    arrowHead[2] = wxPoint(size_h/2-conductor_width_r2 * 0.5 - conductor_separation_r2 +5,size_v/2 + conductor_height_r2+3);
    dc.DrawPolygon(WXSIZEOF(arrowHead), arrowHead);

    arrowHead[0] = wxPoint(size_h/2-conductor_width_r2 * 0.5 ,size_v/2 + conductor_height_r2);
    arrowHead[1] = wxPoint(size_h/2-conductor_width_r2 * 0.5 -5,size_v/2 + conductor_height_r2-3);
    arrowHead[2] = wxPoint(size_h/2-conductor_width_r2 * 0.5 -5,size_v/2 + conductor_height_r2+3);
    dc.DrawPolygon(WXSIZEOF(arrowHead), arrowHead);



    arrowHead[0] = wxPoint(size_h/2-5-conductor_width_r2 * 1.5 - conductor_separation_r2,size_v/2);
    arrowHead[1] = wxPoint(size_h/2-5-conductor_width_r2 * 1.5 - conductor_separation_r2 - 3,size_v/2 - 5);
    arrowHead[2] = wxPoint(size_h/2-5-conductor_width_r2 * 1.5 - conductor_separation_r2 + 3,size_v/2 - 5);
    dc.DrawPolygon(WXSIZEOF(arrowHead), arrowHead);

    arrowHead[0] = wxPoint(size_h/2-5-conductor_width_r2 * 1.5 - conductor_separation_r2,size_v/2 - conductor_height_r2);
    arrowHead[1] = wxPoint(size_h/2-5-conductor_width_r2 * 1.5 - conductor_separation_r2 - 3,size_v/2 - conductor_height_r2 + 5);
    arrowHead[2] = wxPoint(size_h/2-5-conductor_width_r2 * 1.5 - conductor_separation_r2 + 3,size_v/2 - conductor_height_r2 + 5);
    dc.DrawPolygon(WXSIZEOF(arrowHead), arrowHead);

}

void FLEXCABLE::OnHighlightSchematic(wxCommandEvent& event)
{
    flexcableSchematic();

    int ID = event.GetId();
    event.Skip(true);

    int size_h, size_v;
    Panel1->GetSize(&size_h, &size_v );

    float conductor_width_r1, conductor_height_r1, conductor_width_r2, conductor_height_r2,conductor_width_r3, conductor_height_r3,conductor_separation_r1, conductor_separation_r2,totalHeight, totalWidth;

    conductor_width_r1 = 0.175 * size_h;
    conductor_height_r1 = 0.06 * size_v;

    conductor_width_r2 = 0.175 * size_h;
    conductor_height_r2 = 0.04 * size_v;

    conductor_width_r3 = 0.9 * size_h;
    conductor_height_r3 = 0.02 * size_v;

    conductor_separation_r1 = 0.05 * size_h;
    conductor_separation_r2 = 0.1 * size_h;

    totalHeight = 0.5 * size_v;
    totalWidth = 0.98 * size_h;

    wxClientDC dc(Panel1);

    wxPoint arrowHead[3];

    if ( ID == ID_TEXTCTRL14)
    {

        dc.SetPen(wxPen(wxColor(51,51,255), 3));
        dc.SetBrush(wxBrush(wxColor(51,51,255), wxSOLID));

        //row 1
        dc.DrawRectangle(wxPoint(size_h/2- 2 * conductor_width_r1 - 2 * conductor_separation_r1, size_v/3-conductor_height_r1/2), wxSize(conductor_width_r1,conductor_height_r1));
        dc.DrawRectangle(wxPoint(size_h/2- conductor_width_r1 - conductor_separation_r1, size_v/3-conductor_height_r1/2), wxSize(conductor_width_r1,conductor_height_r1));
        dc.DrawRectangle(wxPoint(size_h/2 + conductor_width_r1 + conductor_separation_r1 , size_v/3-conductor_height_r1/2), wxSize(conductor_width_r1,conductor_height_r1));

        //row 2
        dc.DrawRectangle(wxPoint(size_h/2 - 1.5 * conductor_width_r2 - conductor_separation_r2, size_v/2-conductor_height_r2), wxSize(conductor_width_r2,conductor_height_r2));
        dc.DrawRectangle(wxPoint(size_h/2 - conductor_width_r2/2, size_v/2-conductor_height_r2), wxSize(conductor_width_r2,conductor_height_r2));

        // row n
        dc.DrawRectangle(wxPoint(size_h/2 - conductor_width_r3/2, size_v/2 + totalHeight/4 ), wxSize(conductor_width_r3,conductor_height_r3));
    }


//    if ( ID == ID_TEXTCTRL2)
//    {
//        dc.SetPen(wxPen(wxColor(51,51,255), 3));
//        dc.SetBrush(wxBrush(wxColor(51,51,255), wxSOLID));
//        dc.DrawLine( size_h/2 - conductor_width - conductor_separation,size_v/2, size_h/2 - conductor_separation,size_v/2 );
//
//        arrowHead[0] = wxPoint(size_h/2 - conductor_width - conductor_separation,size_v/2);
//        arrowHead[1] = wxPoint(size_h/2 - conductor_width - conductor_separation+5,size_v/2-3);
//        arrowHead[2] = wxPoint(size_h/2 - conductor_width - conductor_separation+5,size_v/2+3);
//        dc.DrawPolygon(WXSIZEOF(arrowHead), arrowHead);
//
//        arrowHead[0] = wxPoint(size_h/2 - conductor_separation,size_v/2);
//        arrowHead[1] = wxPoint(size_h/2 - conductor_separation-5,size_v/2-3);
//        arrowHead[2] = wxPoint(size_h/2 - conductor_separation-5,size_v/2+3);
//        dc.DrawPolygon(WXSIZEOF(arrowHead), arrowHead);
//    }
//
//    if ( ID == ID_TEXTCTRL3)
//    {
//        dc.SetPen(wxPen(wxColor(51,51,255), 3));
//        dc.SetBrush(wxBrush(wxColor(51,51,255), wxSOLID));
//        dc.DrawLine( size_h/2 - conductor_separation,size_v/2-conductor_height/2, size_h/2 - conductor_separation,size_v/2 + conductor_height/2);
//
//        arrowHead[0] = wxPoint(size_h/2 - conductor_separation,size_v/2-conductor_height/2);
//        arrowHead[1] = wxPoint(size_h/2 - conductor_separation - 3,size_v/2-conductor_height/2 + 5);
//        arrowHead[2] = wxPoint(size_h/2 - conductor_separation + 3,size_v/2-conductor_height/2 + 5);
//        dc.DrawPolygon(WXSIZEOF(arrowHead), arrowHead);
//
//        arrowHead[0] = wxPoint(size_h/2 - conductor_separation,size_v/2 + conductor_height/2);
//        arrowHead[1] = wxPoint(size_h/2 - conductor_separation - 3,size_v/2 + conductor_height/2 - 5);
//        arrowHead[2] = wxPoint(size_h/2 - conductor_separation + 3,size_v/2 + conductor_height/2 - 5);
//        dc.DrawPolygon(WXSIZEOF(arrowHead), arrowHead);
//    }
//
//    if ( ID == ID_TEXTCTRL4)
//    {
//        dc.SetPen(wxPen(wxColor(51,51,255), 3));
//        dc.SetBrush(wxBrush(wxColor(51,51,255), wxSOLID));
//        dc.DrawLine( size_h/2 - conductor_width - 2 * conductor_separation,size_v/2, size_h/2 - conductor_width - conductor_separation,size_v/2);
//
//        arrowHead[0] = wxPoint(size_h/2 - conductor_width - 2 * conductor_separation,size_v/2);
//        arrowHead[1] = wxPoint(size_h/2 - conductor_width - 2 * conductor_separation + 5,size_v/2 - 3);
//        arrowHead[2] = wxPoint(size_h/2 - conductor_width - 2 * conductor_separation + 5,size_v/2 + 3);
//        dc.DrawPolygon(WXSIZEOF(arrowHead), arrowHead);
//
//        arrowHead[0] = wxPoint(size_h/2 - conductor_width - conductor_separation,size_v/2);
//        arrowHead[1] = wxPoint(size_h/2 - conductor_width - conductor_separation - 5,size_v/2 - 3);
//        arrowHead[2] = wxPoint(size_h/2 - conductor_width - conductor_separation - 5,size_v/2 + 3);
//        dc.DrawPolygon(WXSIZEOF(arrowHead), arrowHead);
//    }
//
//    if ( ID == ID_TEXTCTRL5)
//    {
//        dc.SetPen(wxPen(wxColor(51,51,255), 3));
//        dc.SetBrush(wxBrush(wxColor(51,51,255), wxSOLID));
//        dc.DrawLine( size_h/2 - totalWidth/2, size_v/2, size_h/2 - 2 * conductor_width - 2 * conductor_separation,size_v/2);
//
//        arrowHead[0] = wxPoint(size_h/2 - totalWidth/2, size_v/2);
//        arrowHead[1] = wxPoint(size_h/2 - totalWidth/2 + 5, size_v/2 - 3);
//        arrowHead[2] = wxPoint(size_h/2 - totalWidth/2 + 5, size_v/2 + 3);
//        dc.DrawPolygon(WXSIZEOF(arrowHead), arrowHead);
//
//        arrowHead[0] = wxPoint(size_h/2 - 2 * conductor_width - 2 * conductor_separation,size_v/2);
//        arrowHead[1] = wxPoint(size_h/2 - 2 * conductor_width - 2 * conductor_separation - 5,size_v/2 - 3);
//        arrowHead[2] = wxPoint(size_h/2 - 2 * conductor_width - 2 * conductor_separation - 5,size_v/2 + 3);
//        dc.DrawPolygon(WXSIZEOF(arrowHead), arrowHead);
//
//    }
//
//    if ( ID == ID_TEXTCTRL6)
//    {
//        dc.SetPen(wxPen(wxColor(51,51,255), 3));
//        dc.SetBrush(wxBrush(wxColor(51,51,255), wxSOLID));
//        dc.DrawLine( size_h/2 - conductor_separation,size_v/2 - conductor_height/2, size_h/2 - conductor_separation,size_v/2 - totalHeight/2);
//
//        arrowHead[0] = wxPoint(size_h/2 - conductor_separation,size_v/2 - conductor_height/2);
//        arrowHead[1] = wxPoint(size_h/2 - conductor_separation - 3,size_v/2 - conductor_height/2 - 5);
//        arrowHead[2] = wxPoint(size_h/2 - conductor_separation + 3,size_v/2 - conductor_height/2 - 5);
//        dc.DrawPolygon(WXSIZEOF(arrowHead), arrowHead);
//
//        arrowHead[0] = wxPoint(size_h/2 - conductor_separation,size_v/2 - totalHeight/2);
//        arrowHead[1] = wxPoint(size_h/2 - conductor_separation - 3,size_v/2 - totalHeight/2 +5);
//        arrowHead[2] = wxPoint(size_h/2 - conductor_separation + 3,size_v/2 - totalHeight/2 + 5);
//        dc.DrawPolygon(WXSIZEOF(arrowHead), arrowHead);
//    }
//    if ( ID == ID_TEXTCTRL14)
//    {
//        dc.SetPen(wxPen(wxColor(51,51,255), 3));
//        dc.SetBrush(wxBrush(wxColor(51,51,255), wxSOLID));
//        dc.DrawRectangle(wxPoint(size_h/2-conductor_width-conductor_separation, size_v/2-conductor_height/2), wxSize(conductor_width,conductor_height));
//        dc.DrawRectangle(wxPoint(size_h/2-(2* conductor_width)-(2*conductor_separation), size_v/2-conductor_height/2), wxSize(conductor_width,conductor_height));
//        dc.DrawRectangle(wxPoint(size_h/2 + conductor_separation, size_v/2-conductor_height/2), wxSize(conductor_width,conductor_height));
//        dc.DrawRectangle(wxPoint(size_h/2 + conductor_width +(2*conductor_separation), size_v/2-conductor_height/2), wxSize(conductor_width,conductor_height));
//
//    }

    if ( ID == ID_TEXTCTRL12 || ID == ID_CHECKBOX1 || ID == ID_TEXTCTRL2 || ID == ID_TEXTCTRL3)
    {
    dc.SetPen( wxPen( wxColor(51,51,255),1 ) );
    dc.SetBrush(wxBrush(wxColor(51,51,255), wxBDIAGONAL_HATCH));
    dc.DrawRectangle(wxPoint(size_h/2-totalWidth/2, size_v/2-totalHeight/2), wxSize(totalWidth,totalHeight));

    dc.SetPen( wxPen( wxColor(192,192,192),1 ) );
    dc.SetBrush(wxBrush(wxColor(224,224,224), wxSOLID));

    //row 1
    dc.DrawRectangle(wxPoint(size_h/2- 2 * conductor_width_r1 - 2 * conductor_separation_r1, size_v/3-conductor_height_r1/2), wxSize(conductor_width_r1,conductor_height_r1));
    dc.DrawRectangle(wxPoint(size_h/2- conductor_width_r1 - conductor_separation_r1, size_v/3-conductor_height_r1/2), wxSize(conductor_width_r1,conductor_height_r1));
    dc.DrawRectangle(wxPoint(size_h/2 + conductor_width_r1 + conductor_separation_r1 , size_v/3-conductor_height_r1/2), wxSize(conductor_width_r1,conductor_height_r1));

    //row 2
    dc.DrawRectangle(wxPoint(size_h/2 - 1.5 * conductor_width_r2 - conductor_separation_r2, size_v/2-conductor_height_r2), wxSize(conductor_width_r2,conductor_height_r2));
    dc.DrawRectangle(wxPoint(size_h/2 - conductor_width_r2/2, size_v/2-conductor_height_r2), wxSize(conductor_width_r2,conductor_height_r2));

    // row n
    dc.DrawRectangle(wxPoint(size_h/2 - conductor_width_r3/2, size_v/2 + totalHeight/4 ), wxSize(conductor_width_r3,conductor_height_r3));

    dc.SetPen( wxPen( wxColor(0,0,0),4, wxDOT ) );
    dc.DrawLine( size_h/2 - conductor_separation_r1 , size_v/3, size_h/2 + conductor_width_r1 + conductor_separation_r1, size_v/3);
    dc.DrawLine( size_h/2 - conductor_width_r2/2 , size_v/2 - conductor_height_r2/2 , size_h/2 - conductor_width_r2/2 - conductor_separation_r2, size_v/2 - conductor_height_r2/2);

    //dc.SetPen( wxPen( wxColor(0,0,0),4, wxDOT ) );
    //dc.DrawLine( size_h/2 - conductor_separation, size_v/2, size_h/2 + conductor_separation, size_v/2);

    }

//    if ( ID == ID_GRID1)
//    {
//
//        dc.SetPen( wxPen( wxColor(51,51,255),1 , wxDOT_DASH) );
//        dc.DrawLine( size_h*0.25, size_v/2-conductor_height_r2/2, size_h*0.75,size_v/2-conductor_height_r2/2 );
//        //dc.DrawLine( size_h/2, 0, size_h/2, size_v);
//
//
//    }
}

void FLEXCABLE::OnNotebook1PageChanging(wxNotebookEvent& event)
{
    flexcableSchematic();
}

void FLEXCABLE::OnPanel1LeftDClick(wxMouseEvent& event)
{
    flexcableSchematic();
}

void FLEXCABLE::EditExistingCable()
{
    Close();
}

void FLEXCABLE::OnTextCtrl13TextEnter(wxCommandEvent& event)
{

    int IsError = 0;
    check_is_numeric(TextCtrl13, &IsError);
    check_is_positive(TextCtrl3, &IsError);

    double value_tb13;
    wxString contents_tb13;

    contents_tb13 = TextCtrl13->GetValue();

    contents_tb13.ToDouble(&value_tb13);

    Grid1 -> CreateGrid (value_tb13, 6);

    Grid1->EnableEditing(true);
    Grid1->EnableGridLines(true);

    Grid1 -> SetColLabelValue(0,_("offset x"));
    Grid1 -> SetColLabelValue(1,_("offset y"));
    Grid1 -> SetColLabelValue(2,_("width"));
    Grid1 -> SetColLabelValue(3,_("height"));
    Grid1 -> SetColLabelValue(4,_("separation"));
    Grid1 -> SetColLabelValue(5,_("conductor n"));

    for (int row_num = 0; row_num < value_tb13; row_num++){

        wxString row;
        row << row_num+1;

        Grid1 -> SetRowLabelValue(row_num,_(row));
    }

}

void FLEXCABLE::OnCheckBox3Click(wxCommandEvent& event)
{
    if (CheckBox3->GetValue())
    {
        MESH_PARAM *winMESH_PARAM = new MESH_PARAM(this);

        winMESH_PARAM->TextCtrl1->Disable();
        winMESH_PARAM->TextCtrl3->Disable();
        //winMESH_PARAM->TextCtrl4->Disable();

        if ( winMESH_PARAM->ShowModal() == wxID_OK )
        {
            MESH_PARAM1 = winMESH_PARAM->TextCtrl1->GetValue();
            MESH_PARAM2 = winMESH_PARAM->TextCtrl2->GetValue();
            MESH_PARAM3 = winMESH_PARAM->TextCtrl3->GetValue();
        }
        winMESH_PARAM->Destroy();
    }
    WriteCableFile (TextCtrl1->GetValue());
}

